Re-exports
pub use crate::system::ActorSystem;pub use crate::system::SystemBuilder;pub use crate::system::SystemEvent;pub use crate::system::SystemMsg;pub use crate::actor::*;
Modules
Structs
- A lightweight, typed reference to interact with its underlying actor instance through concurrent messaging.
- A lightweight, un-typed reference to interact with its underlying actor instance through concurrent messaging.
- Wraps message and sender
Traits
- Produces
ActorRefs.actor_ofblocks on the current thread until the actor has successfully started or failed to start. - Produces
ActorRefs under thetempguardian actor.